==> haskell-x509-validation-1.6.8-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-x509-validation.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: x509-validation
version: 1.6.8
id: x509-validation-1.6.8-IJN0VWVZi6mDioSGqJCAAM
key: x509-validation-1.6.8-IJN0VWVZi6mDioSGqJCAAM
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-certificate
synopsis: X.509 Certificate and CRL validation
description:
    X.509 Certificate and CRL validation
category: Data
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Data.X509.Validation
hidden-modules: Data.X509.Validation.Signature
                Data.X509.Validation.Fingerprint Data.X509.Validation.Cache
                Data.X509.Validation.Types
abi: 705101a7496efb84d4bc890911e71e5c
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/x509-validation-1.6.8
library-dirs: /usr/lib/ghc-8.0.2/site-local/x509-validation-1.6.8
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.0.2/x509-validation-1.6.8
hs-libraries: HSx509-validation-1.6.8-IJN0VWVZi6mDioSGqJCAAM
depends:
    asn1-encoding-0.9.5-IYQwkkfu141LtkpgWZ9ola
    asn1-types-0.3.2-9aXDFyarEaR4iFeC6pBR3x base-4.9.1.0
    byteable-0.1.1-2lU1pexQSLj1KbNO17UifQ bytestring-0.10.8.1
    containers-0.5.7.1 cryptonite-0.24-AqnDXA3gQAj4DhJJp41U2O
    data-default-class-0.1.2.0-N42RtcTZUUAlapzICmPz4
    hourglass-0.2.10-pnbvWmzfcY1rOFETQEmcY
    memory-0.14.6-8f3xLObLA3p67pVexclvQP
    mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6 pem-0.2.2-CkEwei5500yF2642aAaOAi
    x509-1.7.2-AiuPvN6jbzg6DtCxEbpLCq
    x509-store-1.6.5-207oZgxuxx4LgKrjjYCdAl
haddock-interfaces: /usr/share/doc/haskell-x509-validation/html/x509-validation.haddock
haddock-html: /usr/share/doc/haskell-x509-validation/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-x509-validation-1.6.9-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-x509-validation.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: x509-validation
version: 1.6.9
id: x509-validation-1.6.9-8UzVuWb21yII0rkU88EA7F
key: x509-validation-1.6.9-8UzVuWb21yII0rkU88EA7F
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-certificate
synopsis: X.509 Certificate and CRL validation
description:
    X.509 Certificate and CRL validation
category: Data
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Data.X509.Validation
hidden-modules: Data.X509.Validation.Signature
                Data.X509.Validation.Fingerprint Data.X509.Validation.Cache
                Data.X509.Validation.Types
abi: fc1957921980e70151519d2dd030a445
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/x509-validation-1.6.9
library-dirs: /usr/lib/ghc-8.0.2/site-local/x509-validation-1.6.9
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.0.2/x509-validation-1.6.9
hs-libraries: HSx509-validation-1.6.9-8UzVuWb21yII0rkU88EA7F
depends:
    asn1-encoding-0.9.5-IYQwkkfu141LtkpgWZ9ola
    asn1-types-0.3.2-9aXDFyarEaR4iFeC6pBR3x base-4.9.1.0
    byteable-0.1.1-2lU1pexQSLj1KbNO17UifQ bytestring-0.10.8.1
    containers-0.5.7.1 cryptonite-0.24-AqnDXA3gQAj4DhJJp41U2O
    data-default-class-0.1.2.0-N42RtcTZUUAlapzICmPz4
    hourglass-0.2.10-pnbvWmzfcY1rOFETQEmcY
    memory-0.14.6-8f3xLObLA3p67pVexclvQP
    mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6 pem-0.2.2-CkEwei5500yF2642aAaOAi
    x509-1.7.2-AiuPvN6jbzg6DtCxEbpLCq
    x509-store-1.6.5-207oZgxuxx4LgKrjjYCdAl
haddock-interfaces: /usr/share/doc/haskell-x509-validation/html/x509-validation.haddock
haddock-html: /usr/share/doc/haskell-x509-validation/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
